%define anolis_release 2

%global with_nss 0
%global ldaplib ldap

# Disable .la file removal since the .la file is exported via apu-config.
%global __brp_remove_la_files %nil

%define apuver 1

Summary: Apache Portable Runtime Utility library
Name: apr-util
Version: 1.6.3
Epoch: 1
Release: %{anolis_release}%{?dist}
License: ASL 2.0
URL: https://apr.apache.org/
Source0: https://www.apache.org/dist/apr/%{name}-%{version}.tar.bz2
Patch1: apr-util-1.2.7-pkgconf.patch
Patch2: apr-util-1.4.1-private.patch
BuildRequires: gcc
BuildRequires: autoconf, apr-devel >= 1.3.0
BuildRequires: expat-devel, libuuid-devel

Recommends: apr-util-openssl = %{EVR}


%description
The mission of the Apache Portable Runtime (APR) is to provide a
free library of C data structures and routines.  This library
contains additional utility interfaces for APR; including support
for XML, LDAP, database interfaces, URI parsing and more.

%package devel
Summary: APR utility library development kit
Requires: apr-util = %{EVR}
Requires: expat-devel, openldap-devel

%description devel
This package provides the support files which can be used to 
build applications using the APR utility library.  The mission 
of the Apache Portable Runtime (APR) is to provide a free 
library of C data structures and routines.

%package pgsql
Summary: APR utility library PostgreSQL DBD driver
BuildRequires: libpq-devel
Requires: apr-util = %{EVR}

%description pgsql
This package provides the PostgreSQL driver for the apr-util
DBD (database abstraction) interface.

%package mysql
Summary: APR utility library MySQL DBD driver
BuildRequires: mariadb-connector-c-devel
Requires: apr-util = %{EVR}

%description mysql
This package provides the MySQL driver for the apr-util DBD
(database abstraction) interface.

%package sqlite
Summary: APR utility library SQLite DBD driver
BuildRequires: sqlite-devel >= 3.0.0
Requires: apr-util = %{EVR}

%description sqlite
This package provides the SQLite driver for the apr-util DBD
(database abstraction) interface.

%package odbc
Summary: APR utility library ODBC DBD driver
BuildRequires: unixODBC-devel
Requires: apr-util = %{EVR}

%description odbc
This package provides the ODBC driver for the apr-util DBD
(database abstraction) interface.

%package ldap
Summary: APR utility library LDAP support
BuildRequires: openldap-devel
Requires: apr-util = %{EVR}

%description ldap
This package provides the LDAP support for the apr-util.

%package openssl
Summary: APR utility library OpenSSL crypto support
BuildRequires: openssl-devel
Requires: apr-util = %{EVR}

%description openssl
This package provides the OpenSSL crypto support for the apr-util.

%if %{with_nss}
%package nss
Summary: APR utility library NSS crypto support
BuildRequires: nss-devel
BuildRequires: make
Requires: apr-util = %{EVR}

%description nss
This package provides the NSS crypto support for the apr-util.
%endif

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{EVR}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

: Configured for LDAP library: %{ldaplib}

%build
autoheader && autoconf
# A fragile autoconf test which fails if the code trips
# any other warning; force correct result for OpenLDAP:
export ac_cv_ldap_set_rebind_proc_style=three
%configure --with-apr=%{_prefix} \
        --includedir=%{_includedir}/apr-%{apuver} \
        --with-ldap=%{ldaplib} --with-gdbm \
        --with-sqlite3 --with-pgsql --with-mysql --with-odbc \
        --with-dbm=gdbm --without-berkeley-db \
        --without-sqlite2 \
        --with-crypto --with-openssl \
%if %{with_nss}
        --with-nss \
%else
        --without-nss \
%endif
   || { cat config.log; exit 1; }
%{make_build}

%install
%{make_install}

mkdir -p $RPM_BUILD_ROOT/%{_datadir}/aclocal
install -m 644 build/find_apu.m4 $RPM_BUILD_ROOT/%{_datadir}/aclocal

# Unpackaged files; remove the static libaprutil
rm -f $RPM_BUILD_ROOT%{_libdir}/aprutil.exp \
      $RPM_BUILD_ROOT%{_libdir}/libapr*.a

# And remove the reference to the static libaprutil from the .la
# file.
sed -i '/^old_library/s,libapr.*\.a,,' \
      $RPM_BUILD_ROOT%{_libdir}/libapr*.la

# Remove unnecessary exports from dependency_libs
sed -ri '/^dependency_libs/{s,-l(pq|sqlite[0-9]|rt|dl|uuid) ,,g}' \
      $RPM_BUILD_ROOT%{_libdir}/libapr*.la

# Trim libtool DSO cruft
rm -f $RPM_BUILD_ROOT%{_libdir}/apr-util-%{apuver}/*.*a

%check
# Run the less verbose test suites
export MALLOC_CHECK_=2 MALLOC_PERTURB_=$(($RANDOM % 255 + 1))
cd test
%{make_build} testall
# testall breaks with DBD DSO; ignore
export LD_LIBRARY_PATH=%{buildroot}/%{_libdir}/apr-util-%{apuver}
./testall -v -q

%generate_compatibility_deps

%files
%{_libdir}/libaprutil-%{apuver}.so.*
%dir %{_libdir}/apr-util-%{apuver}
%dir %{abidir}
%{abidir}/libaprutil-%{apuver}.dump

%files doc
%doc CHANGES LICENSE NOTICE

%files pgsql
%{_libdir}/apr-util-%{apuver}/apr_dbd_pgsql*
%{abidir}/apr_dbd_pgsql-%{apuver}.dump

%files mysql
%{_libdir}/apr-util-%{apuver}/apr_dbd_mysql*
%{abidir}/apr_dbd_mysql-%{apuver}.dump

%files sqlite
%{_libdir}/apr-util-%{apuver}/apr_dbd_sqlite*
%{abidir}/apr_dbd_sqlite3-%{apuver}.dump

%files odbc
%{_libdir}/apr-util-%{apuver}/apr_dbd_odbc*
%{abidir}/apr_dbd_odbc-%{apuver}.dump

%files ldap
%{_libdir}/apr-util-%{apuver}/apr_ldap*
%{abidir}/apr_ldap-%{apuver}.dump

%files openssl
%{_libdir}/apr-util-%{apuver}/apr_crypto_openssl*
%{abidir}/apr_crypto_openssl-%{apuver}.dump

%if %{with_nss}
%files nss
%{_libdir}/apr-util-%{apuver}/apr_crypto_nss*
%endif

%files devel
%{_bindir}/apu-%{apuver}-config
%{_libdir}/libaprutil-%{apuver}.la
%{_libdir}/libaprutil-%{apuver}.so
%{_includedir}/apr-%{apuver}/*.h
%{_libdir}/pkgconfig/*.pc
%{_datadir}/aclocal/*.m4

%changelog
* Sat Mar 4 2023 Funda Wang <fundawang@yeah.net> - 1:1.6.3-2
- Rebuild for new libpq

* Thu Feb 9 2023 Funda Wang <fundawang@yeah.net> - 1:1.6.3-1
- New version 1.6.3

* Mon Jan 09 2023 Kaihao Bai <carlo.bai@linux.alibaba.com> - 1:1.6.1-3
- add doc package and optimize spec

* Fri May 27 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:1.6.1-2
- add epoch to require version

* Fri May 27 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1:1.6.1-1
- init from upstream
- remove dependency of libdb
